package com.acquisition.Controller;

import com.acquisition.service.DataAcquisition.FileProcessorConfigService;
import com.acquisition.service.DataAcquisition.FileProcessorService;
import com.acquisition.service.DataAcquisition.FilesdataCopy;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author wang
 * @since 2025-01-07
 */
@RestController
@RequestMapping("/data-acquisition")
public class DataAcquisitionController {

    @Autowired
    private FileProcessorService fileProcessorService;

    @Autowired
    private FileProcessorConfigService configService;

    @Autowired
    private FilesdataCopy filesdataCopy;



    /**
     * 创建data文件并复制demo文件
     *
     * @return 完成信息
     * @throws Exception 如果处理文件时出现错误
     */
    @GetMapping("/fileprocess")
    @Operation(summary = "创建data文件并复制demo文件", description = "执行创建data文件并复制demo文件")
    @ApiResponse(responseCode = "200", description = "成功返回完成信息",
            content = @Content(mediaType = "text/plain",
                    schema = @Schema(implementation = String.class)))
    public String fileprocess() throws Exception {
        fileProcessorService.processFiles();
        return "文件夹创建已完成";
    }

    /**
     * 数据自动采集
     *
     * @return 完成信息
     * @throws Exception 如果处理文件时出现错误
     */
    @GetMapping("/fileprocessconfig")
    @Operation(summary = "数据自动采集配置", description = "数据自动采集配置")
    @ApiResponse(responseCode = "200", description = "成功返回完成信息",
            content = @Content(mediaType = "text/plain",
                    schema = @Schema(implementation = String.class)))
    public String fileprocessconfig() throws Exception {
        configService.processFiles();
        return "数据自动配置已完成";
    }

    /**
     * 104转发协议测点
     *
     * @return 完成信息
     * @throws Exception 如果处理文件时出现错误
     */
    @GetMapping("/copyfiledata")
    @Operation(summary = "104转发协议测点配置", description = "104转发协议测点配置")
    @ApiResponse(responseCode = "200", description = "成功返回完成信息",
            content = @Content(mediaType = "text/plain",
                    schema = @Schema(implementation = String.class)))
    public String filecopydata() throws Exception {
        filesdataCopy.processFiles();
        return "104转发协议测点配置完成";
    }
}
